@@ -44,10 +44,10 @@ class plot:
         self.run()
 
     def main(self):
-        self.method_style()
-
         self.method_setup()
 
+        self.method_style()
+
         # Scale axes
         self.method_scale()
 
@@ -95,7 +95,8 @@ class plot:
                 self.ax = self.plt.gca()
 
         if isinstance(self.ax, type(None)):
-            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box', projection='3d')
+            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box', projection='3d',
+                                           facecolor=self.background_color_figure)
 
         self.ax.view_init(azim=self.azim, elev=self.elev)
 
@@ -132,16 +133,62 @@ class plot:
 
     def method_resize_axes(self):
         if self.resize_axes is True:
-            self.z_pad = 0
-            if isinstance(self.x_bounds, type(None)):
-                self.x_bounds = (self.x.min(), self.x.max())
-            if isinstance(self.y_bounds, type(None)):
-                self.y_bounds = (self.y.min(), self.y.max())
-            if isinstance(self.z_bounds, type(None)):
-                self.z_bounds = (self.z.min(), self.z.max())
-            self.ax.set_xlim3d(self.x_bounds[0] - self.x_pad, self.x_bounds[1] + self.x_pad)
-            self.ax.set_ylim3d(self.y_bounds[0] - self.y_pad, self.y_bounds[1] + self.y_pad)
-            self.ax.set_zlim3d(self.z_bounds[0] - self.z_pad, self.z_bounds[1] + self.z_pad)
+
+            def bounds(d, u, l, up, lp, v):
+                # Upper and lower bounds
+                if isinstance(u, type(None)):
+                    u = d.max()
+                else:
+                    up = 0
+                if isinstance(l, type(None)):
+                    l = d.min()
+                else:
+                    lp = 0
+                # Bounds vector
+                if isinstance(v, type(None)):
+                    v = [self.x_lower_bound, self.x_upper_bound]
+                if isinstance(v[0], type(None)):
+                    v[0] = l
+                if isinstance(v[1], type(None)):
+                    v[1] = u
+                return v, up, lp
+
+            self.x_bounds, self.x_upper_resize_pad, self.x_lower_resize_pad = bounds(self.x,
+                                                                                     self.x_upper_bound,
+                                                                                     self.x_lower_bound,
+                                                                                     self.x_upper_resize_pad,
+                                                                                     self.x_lower_resize_pad,
+                                                                                     self.x_bounds)
+            self.y_bounds, self.y_upper_resize_pad, self.y_lower_resize_pad = bounds(self.y,
+                                                                                     self.y_upper_bound,
+                                                                                     self.y_lower_bound,
+                                                                                     self.y_upper_resize_pad,
+                                                                                     self.y_lower_resize_pad,
+                                                                                     self.y_bounds)
+            self.z_bounds, self.z_upper_resize_pad, self.z_lower_resize_pad = bounds(self.z,
+                                                                                     self.z_upper_bound,
+                                                                                     self.z_lower_bound,
+                                                                                     self.z_upper_resize_pad,
+                                                                                     self.z_lower_resize_pad,
+                                                                                     self.z_bounds)
+
+            if self.demo_pad_plot is True:
+                pad_x = 0.05 * (abs(self.x.max()) + abs(self.x.min()))
+                self.x_upper_resize_pad = pad_x
+                self.x_lower_resize_pad = pad_x
+                pad_y = 0.05 * (abs(self.y.max()) + abs(self.y.min()))
+                self.y_upper_resize_pad = pad_y
+                self.y_lower_resize_pad = pad_y
+                pad_z = 0.05 * (abs(self.z.max()) + abs(self.z.min()))
+                self.z_upper_resize_pad = pad_z
+                self.z_lower_resize_pad = pad_z
+
+            self.ax.set_xlim3d(self.x_bounds[0] - self.x_lower_resize_pad,
+                               self.x_bounds[1] + self.x_upper_resize_pad)
+            self.ax.set_ylim3d(self.y_bounds[0] - self.y_lower_resize_pad,
+                               self.y_bounds[1] + self.y_upper_resize_pad)
+            self.ax.set_zlim3d(self.z_bounds[0] - self.y_lower_resize_pad,
+                               self.z_bounds[1] + self.y_upper_resize_pad)
 
     def method_save(self):
         if self.filename:
@@ -389,11 +436,20 @@ class line(plot):
                  fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10, spines_removed=('top', 'right'),
-                 workspace_color=None, workspace_color2=None, light=None, dark=None, pane_fill=None,
+                 workspace_color=None, workspace_color2=None,
+                 background_color_figure='white', background_color_plot='white',
+                 style=None, light=None, dark=None,
+                 pane_fill=None,
                  # Bounds
+                 x_upper_bound=None, x_lower_bound=None,
+                 y_upper_bound=None, y_lower_bound=None,
+                 z_upper_bound=None, z_lower_bound=None,
                  x_bounds=None, y_bounds=None, z_bounds=None,
                  # Pads
-                 x_pad=0, y_pad=0, z_pad=0,
+                 demo_pad_plot=False,
+                 x_upper_resize_pad=0, x_lower_resize_pad=0,
+                 y_upper_resize_pad=0, y_lower_resize_pad=0,
+                 z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
                  grid=False, grid_color='black', grid_lines='-.',
                  # Color
@@ -401,15 +457,15 @@ class line(plot):
                  # Title
                  title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=5, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=5, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=5, z_label_rotation=None,
+                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
                  z_tick_number=5, z_tick_labels=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
-                 tick_color=None, tick_label_pad=5, tick_ndecimals=1,
+                 tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
                  tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
                  # Color bar
@@ -467,11 +523,20 @@ class scatter(plot, color):
                  fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10, spines_removed=('top', 'right'),
-                 workspace_color=None, workspace_color2=None, light=None, dark=None, pane_fill=None,
+                 workspace_color=None, workspace_color2=None,
+                 background_color_figure='white', background_color_plot='white',
+                 style=None, light=None, dark=None,
+                 pane_fill=None,
                  # Bounds
+                 x_upper_bound=None, x_lower_bound=None,
+                 y_upper_bound=None, y_lower_bound=None,
+                 z_upper_bound=None, z_lower_bound=None,
                  x_bounds=None, y_bounds=None, z_bounds=None,
                  # Pads
-                 x_pad=0, y_pad=0, z_pad=0,
+                 demo_pad_plot=False,
+                 x_upper_resize_pad=0, x_lower_resize_pad=0,
+                 y_upper_resize_pad=0, y_lower_resize_pad=0,
+                 z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
                  grid=False, grid_color='black', grid_lines='-.',
                  # Color
@@ -479,15 +544,15 @@ class scatter(plot, color):
                  # Title
                  title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=5, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=5, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=5, z_label_rotation=None,
+                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
                  z_tick_number=5, z_tick_labels=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
-                 tick_color=None, tick_label_pad=5, tick_ndecimals=1,
+                 tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
                  tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
                  # Color bar
@@ -557,11 +622,20 @@ class surface(plot, surf):
                  fig=None, ax=None, figsize=None, shape_and_position=111, azim=54, elev=25,
                  # Setup
                  prune=None, resize_axes=True, aspect=1, box_to_plot_pad=10, spines_removed=('top', 'right'),
-                 workspace_color=None, workspace_color2=None, light=None, dark=None, pane_fill=None,
+                 workspace_color=None, workspace_color2=None,
+                 background_color_figure='white', background_color_plot='white',
+                 style=None, light=None, dark=None,
+                 pane_fill=None,
                  # Bounds
+                 x_upper_bound=None, x_lower_bound=None,
+                 y_upper_bound=None, y_lower_bound=None,
+                 z_upper_bound=None, z_lower_bound=None,
                  x_bounds=None, y_bounds=None, z_bounds=None,
                  # Pads
-                 x_pad=0, y_pad=0, z_pad=0,
+                 demo_pad_plot=False,
+                 x_upper_resize_pad=0, x_lower_resize_pad=0,
+                 y_upper_resize_pad=0, y_lower_resize_pad=0,
+                 z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
                  grid=False, grid_color='black', grid_lines='-.',
                  # Color
@@ -569,15 +643,15 @@ class surface(plot, surf):
                  # Title
                  title=None, title_weight=None, title_size=12, title_y=1.025, title_color=None, title_font=None,
                  # Labels
-                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=5, x_label_rotation=None,
-                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=5, y_label_rotation=None,
-                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=5, z_label_rotation=None,
+                 x_label='x', x_label_bold=False, x_label_size=12, x_label_pad=7, x_label_rotation=None,
+                 y_label='y', y_label_bold=False, y_label_size=12, y_label_pad=7, y_label_rotation=None,
+                 z_label='z', z_label_bold=False, z_label_size=12, z_label_pad=7, z_label_rotation=None,
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
                  z_tick_number=5, z_tick_labels=None,
                  x_tick_rotation=None, y_tick_rotation=None, z_tick_rotation=None,
-                 tick_color=None, tick_label_pad=5, tick_ndecimals=1,
+                 tick_color=None, tick_label_pad=4, tick_ndecimals=1,
                  # Tick labels
                  tick_label_size=8.5, tick_label_size_x=None, tick_label_size_y=None, tick_label_size_z=None,
                  # Color bar
